==> cms_content_sync-8.x-1.43.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/entity_handler/DefaultConfigEntityHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler;

use Drupal\cms_content_sync\PushIntent;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\Plugin\EntityHandlerBase;
use Drupal\cms_content_sync\SyncIntent;
use Drupal\Core\Entity\EntityInterface;

/**
 * Class DefaultConfigEntityHandler, providing a minimalistic implementation for
 * any config entity type.
 *
 * @EntityHandler(
 *   id = "cms_content_sync_default_config_entity_handler",
 *   label = @Translation("Default Config"),
 *   weight = 100
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler
 */
class DefaultConfigEntityHandler extends EntityHandlerBase {

  /**
   * @inheritdoc
   */
  public static function supports($entity_type, $bundle) {
    // Whitelist supported entity types.
    $entity_types = [
      'webform',
    ];

    return in_array($entity_type, $entity_types);
  }

  /**
   * Get all config properties for this entity type.
   *
   * @return array
   */
  protected function getConfigProperties() {
    /**
     * @var \Drupal\Core\Config\Entity\ConfigEntityTypeInterface $entity_type
     */
    $entity_type = \Drupal::entityTypeManager()->getDefinition($this->entityTypeName);

    $properties = $entity_type->getPropertiesToExport();
    if (!$properties) {
      return [];
    }

    $config_definition = \Drupal::service('config.typed')->getDefinition($this->entityTypeName . '.' . $this->bundleName . '.*');
    if (empty($config_definition)) {
      return [];
    }

    $mapping = $config_definition['mapping'];

    $result = [];

    foreach ($properties as $property) {
      // Wrong information from webform schema definition...
      // Associative arrays are NOT sequences.
      if ($this->entityTypeName === 'webform' && $property === 'access') {
        $mapping[$property]['type'] = 'mapping';
      }

      $result[$property] = $mapping[$property];
    }

    return $result;
  }

  /**
   * @param  \EdgeBox\SyncCore\Interfaces\Configuration\IDefineEntityType $definition
   */
  public function updateEntityTypeDefinition(&$definition) {
    // Add properties that are listed as "config_export" keys from the entity
    // type annotation.
    $typeMapping = [
      'uuid' => 'string',
      'boolean' => 'boolean',
      'email' => 'string',
      'integer' => 'integer',
      'float' => 'float',
      'string' => 'string',
      'text' => 'string',
      'label' => 'string',
      'uri' => 'string',
      'mapping' => 'object',
      'sequence' => 'object',
    ];

    foreach ($this->getConfigProperties() as $key => $config) {
      $type = $config['type'];
      if (empty($typeMapping[$type])) {
        continue;
      }

      $remoteType = $typeMapping[$type];
      $multiple = FALSE;
      if ($remoteType === 'array') {
        $type = $config['sequence']['type'];
        if (empty($typeMapping[$type])) {
          continue;
        }

        $remoteType = $typeMapping[$type];
        $multiple = TRUE;
      }

      if ($remoteType === 'string') {
        $definition->addStringProperty($key, $multiple);
      }
      elseif ($remoteType === 'boolean') {
        $definition->addBooleanProperty($key, $multiple);
      }
      elseif ($remoteType === 'integer') {
        $definition->addIntegerProperty($key, $multiple);
      }
      elseif ($remoteType === 'float') {
        $definition->addFloatProperty($key, $multiple);
      }
      else {
        $definition->addObjectProperty($key, $multiple);
      }
    }
  }

  /**
   * Check whether the entity type supports having a label.
   *
   * @return bool
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  protected function hasLabelProperty() {
    return TRUE;
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPreviewOptions() {
    return [];
  }

  /**
   * @inheritdoc
   */
  public function push(PushIntent $intent, EntityInterface $entity = NULL) {
    if (!parent::push($intent, $entity)) {
      return FALSE;
    }

    if (!$entity) {
      $entity = $intent->getEntity();
    }

    /**
     * @var \Drupal\Core\Config\Entity\ConfigEntityInterface $entity
     */

    foreach ($this->getConfigProperties() as $property => $config) {
      $entity_property = $entity->get($property);
      if (is_array($entity_property) && !count($entity_property)) {
        $entity_property = NULL;
      }

      $intent->setProperty($property, $entity_property);
    }

    return TRUE;
  }

  /**
   * Pull the remote entity.
   *
   * @inheritdoc
   */
  public function pull(PullIntent $intent) {
    $action = $intent->getAction();

    if (!parent::pull($intent)) {
      return FALSE;
    }

    if ($action === SyncIntent::ACTION_DELETE) {
      return TRUE;
    }

    /**
     * @var \Drupal\Core\Config\Entity\ConfigEntityInterface $entity
     */
    $entity = $intent->getEntity();

    $forbidden_fields = $this->getForbiddenFields();

    foreach ($this->getConfigProperties() as $property => $config) {
      if (in_array($property, $forbidden_fields)) {
        continue;
      }

      $entity->set($property, $intent->getProperty($property));
    }

    $entity->save();

    return TRUE;
  }

}

==> cms_content_sync-8.x-1.44.tar.gz: cms_content_sync/src/Plugin/cms_content_sync/entity_handler/DefaultConfigEntityHandler.php <==
<?php

namespace Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler;

use Drupal;
use Drupal\cms_content_sync\Plugin\EntityHandlerBase;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\PushIntent;
use Drupal\cms_content_sync\SyncIntent;
use Drupal\Core\Entity\EntityInterface;

/**
 * Class DefaultConfigEntityHandler, providing a minimalistic implementation for
 * any config entity type.
 *
 * @EntityHandler(
 *   id = "cms_content_sync_default_config_entity_handler",
 *   label = @Translation("Default Config"),
 *   weight = 100
 * )
 *
 * @package Drupal\cms_content_sync\Plugin\cms_content_sync\entity_handler
 */
class DefaultConfigEntityHandler extends EntityHandlerBase {

  /**
   * @inheritdoc
   */
  public static function supports($entity_type, $bundle) {
    // Whitelist supported entity types.
    $entity_types = [
      'webform',
    ];

    return in_array($entity_type, $entity_types);
  }

  /**
   * Get all config properties for this entity type.
   *
   * @return array
   */
  protected function getConfigProperties() {
    /**
     * @var \Drupal\Core\Config\Entity\ConfigEntityTypeInterface $entity_type
     */
    $entity_type = Drupal::entityTypeManager()->getDefinition($this->entityTypeName);

    $properties = $entity_type->getPropertiesToExport();
    if (!$properties) {
      return [];
    }

    $config_definition = Drupal::service('config.typed')->getDefinition($this->entityTypeName . '.' . $this->bundleName . '.*');
    if (empty($config_definition)) {
      return [];
    }

    $mapping = $config_definition['mapping'];

    $result = [];

    foreach ($properties as $property) {
      // Wrong information from webform schema definition...
      // Associative arrays are NOT sequences.
      if ($this->entityTypeName === 'webform' && $property === 'access') {
        $mapping[$property]['type'] = 'mapping';
      }

      $result[$property] = $mapping[$property];
    }

    return $result;
  }

  /**
   * @param  \EdgeBox\SyncCore\Interfaces\Configuration\IDefineEntityType $definition
   */
  public function updateEntityTypeDefinition(&$definition) {
    // Add properties that are listed as "config_export" keys from the entity
    // type annotation.
    $typeMapping = [
      'uuid' => 'string',
      'boolean' => 'boolean',
      'email' => 'string',
      'integer' => 'integer',
      'float' => 'float',
      'string' => 'string',
      'text' => 'string',
      'label' => 'string',
      'uri' => 'string',
      'mapping' => 'object',
      'sequence' => 'object',
    ];

    foreach ($this->getConfigProperties() as $key => $config) {
      $type = $config['type'];
      if (empty($typeMapping[$type])) {
        continue;
      }

      $remoteType = $typeMapping[$type];
      $multiple = FALSE;
      if ($remoteType === 'array') {
        $type = $config['sequence']['type'];
        if (empty($typeMapping[$type])) {
          continue;
        }

        $remoteType = $typeMapping[$type];
        $multiple = TRUE;
      }

      if ($remoteType === 'string') {
        $definition->addStringProperty($key, $multiple);
      }
      elseif ($remoteType === 'boolean') {
        $definition->addBooleanProperty($key, $multiple);
      }
      elseif ($remoteType === 'integer') {
        $definition->addIntegerProperty($key, $multiple);
      }
      elseif ($remoteType === 'float') {
        $definition->addFloatProperty($key, $multiple);
      }
      else {
        $definition->addObjectProperty($key, $multiple);
      }
    }
  }

  /**
   * Check whether the entity type supports having a label.
   *
   * @return bool
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  protected function hasLabelProperty() {
    return TRUE;
  }

  /**
   * @inheritdoc
   */
  public function getAllowedPreviewOptions() {
    return [];
  }

  /**
   * @inheritdoc
   */
  public function push(PushIntent $intent, EntityInterface $entity = NULL) {
    if (!parent::push($intent, $entity)) {
      return FALSE;
    }

    if (!$entity) {
      $entity = $intent->getEntity();
    }

    /**
     * @var \Drupal\Core\Config\Entity\ConfigEntityInterface $entity
     */

    foreach ($this->getConfigProperties() as $property => $config) {
      $entity_property = $entity->get($property);
      if (is_array($entity_property) && !count($entity_property)) {
        $entity_property = NULL;
      }

      $intent->setProperty($property, $entity_property);
    }

    return TRUE;
  }

  /**
   * Pull the remote entity.
   *
   * @inheritdoc
   */
  public function pull(PullIntent $intent) {
    $action = $intent->getAction();

    if (!parent::pull($intent)) {
      return FALSE;
    }

    if ($action === SyncIntent::ACTION_DELETE) {
      return TRUE;
    }

    /**
     * @var \Drupal\Core\Config\Entity\ConfigEntityInterface $entity
     */
    $entity = $intent->getEntity();

    $forbidden_fields = $this->getForbiddenFields();

    foreach ($this->getConfigProperties() as $property => $config) {
      if (in_array($property, $forbidden_fields)) {
        continue;
      }

      $entity->set($property, $intent->getProperty($property));
    }

    $entity->save();

    return TRUE;
  }

}
